==> ark-17.04.2.tar.xz: ark-17.04.2/plugins/libarchive/kerfuffle_libarchive_readonly.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract DEB, RPM, ISO, AppImage, XAR and CAB files",
        "Description[ca@valencia]": "Obri i extreu fitxers DEB, RPM, ISO, AppImage, XAR i CAB",
        "Description[ca]": "Obre i extreu fitxers DEB, RPM, ISO, AppImage, XAR i CAB",
        "Description[cs]": "Otevřít a rozbalit soubory DEB, RPM, ISO, AppImage, XAR a CAB",
        "Description[de]": "Öffnen und Entpacken von DEB-, RPM-, ISO-, AppImage-, XAR- und CAB-Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή αρχείων DEB, RPM, ISO, AppImage, XAR και CAB",
        "Description[es]": "Abrir y extraer archivos DEB, RPM, ISO, AppImage, XAR y CAB",
        "Description[eu]": "Ireki eta erauzi DEB, RPM, ISO, AppImage, XAR eta CAB fitxategiak",
        "Description[fr]": "Ouvre et extrait les fichiers DEB, RPM, ISO, AppImage, XAR et CAB",
        "Description[it]": "Apri ed estrai file DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[nl]": "Open en pak uit DEB, RPM, ISO, AppImage, XAR en CAB bestanden",
        "Description[pl]": "Otwieraj i wypakowuj pliki DEB, RPM, ISO, AppImage, XAR oraz CAB",
        "Description[pt]": "Abrir e extrair ficheiros DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[sk]": "Otvorenie a extrahovanie súborov DEB, RPM, ISO, AppImage, XAR a CAB",
        "Description[sl]": "Odprite in razširite datoteke DEB, RPM, ISO, AppImage, XAR in CAB",
        "Description[sr@ijekavian]": "Отварање и распакивање ДЕБ, РПМ, ИСО, ап‑имејџ, КСАР и КАБ фајлова",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje DEB, RPM, ISO, AppImage, XAR i CAB fajlova",
        "Description[sr@latin]": "Otvaranje i raspakivanje DEB, RPM, ISO, AppImage, XAR i CAB fajlova",
        "Description[sr]": "Отварање и распакивање ДЕБ, РПМ, ИСО, ап‑имејџ, КСАР и КАБ фајлова",
        "Description[sv]": "Öppna och packa upp DEB-, RPM-, ISO-, AppImage-, XAR- och CAB-filer",
        "Description[uk]": "Здатен відкривати і видобувати дані з архівів DEB, RPM, ISO, AppImage, XAR та CAB",
        "Description[x-test]": "xxOpen and extract DEB, RPM, ISO, AppImage, XAR and CAB filesxx",
        "Description[zh_CN]": "打开和解压 DEB，RPM，ISO，AppImage，XAR 和 CAB 文件",
        "Description[zh_TW]": "開啟並解壓縮 DEB, RPM, ISO, AppImage, XAR 與 CAB 檔案",
        "Id": "kerfuffle_libarchive_readonly",
        "MimeTypes": [
            "@SUPPORTED_READONLY_MIMETYPES@"
        ],
        "Name": "Libarchive plugin (read-only formats)",
        "Name[ca@valencia]": "Connector del Libarchive (formats de només lectura)",
        "Name[ca]": "Connector del Libarchive (formats de només lectura)",
        "Name[cs]": "Modul libarchive (formáty pouze pro čtení)",
        "Name[de]": "LibArchive-Modul (Nur lesbare Formate)",
        "Name[el]": "Πρόσθετο Libarchive (ανάγνωση μόνο)",
        "Name[es]": "Complemento Libarchive (formatos de solo lectura)",
        "Name[eu]": "Libarchive plugina (irakurri-soilik formatuak)",
        "Name[fr]": "Module externe libarchive (formats en lecture seule)",
        "Name[it]": "Estensione Libarchive (formati in sola lettura)",
        "Name[nl]": "LibArchive-plug-in (alleen-lezen formaten)",
        "Name[pl]": "Wtyczka Libarchive (formaty tylko-do-odczytu)",
        "Name[pt]": "'Plugin' da Libarchive (formatos apenas para leitura)",
        "Name[sk]": "Plugin Libarchive (formáty iba na čítanie)",
        "Name[sl]": "Vstavek Libarchive (samo za branje)",
        "Name[sr@ijekavian]": "Прикључак за Либархив (формати само‑за‑читање)",
        "Name[sr@ijekavianlatin]": "Priključak za libarchive (formati samo‑za‑čitanje)",
        "Name[sr@latin]": "Priključak za libarchive (formati samo‑za‑čitanje)",
        "Name[sr]": "Прикључак за Либархив (формати само‑за‑читање)",
        "Name[sv]": "Libarchive-insticksprogram (endast läsningsformat)",
        "Name[uk]": "Додаток libarchive (формати лише для читання)",
        "Name[x-test]": "xxLibarchive plugin (read-only formats)xx",
        "Name[zh_CN]": "Libarchive 插件 (只读格式)",
        "Name[zh_TW]": "Libarchive 外掛程式（唯讀格式）",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": false,
    "X-KDE-Priority": 100
}

==> ark-17.04.3.tar.xz: ark-17.04.3/plugins/libarchive/kerfuffle_libarchive_readonly.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract DEB, RPM, ISO, AppImage, XAR and CAB files",
        "Description[ca@valencia]": "Obri i extreu fitxers DEB, RPM, ISO, AppImage, XAR i CAB",
        "Description[ca]": "Obre i extreu fitxers DEB, RPM, ISO, AppImage, XAR i CAB",
        "Description[cs]": "Otevřít a rozbalit soubory DEB, RPM, ISO, AppImage, XAR a CAB",
        "Description[de]": "Öffnen und Entpacken von DEB-, RPM-, ISO-, AppImage-, XAR- und CAB-Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή αρχείων DEB, RPM, ISO, AppImage, XAR και CAB",
        "Description[es]": "Abrir y extraer archivos DEB, RPM, ISO, AppImage, XAR y CAB",
        "Description[eu]": "Ireki eta erauzi DEB, RPM, ISO, AppImage, XAR eta CAB fitxategiak",
        "Description[fr]": "Ouvre et extrait les fichiers DEB, RPM, ISO, AppImage, XAR et CAB",
        "Description[it]": "Apri ed estrai file DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[nl]": "Open en pak uit DEB, RPM, ISO, AppImage, XAR en CAB bestanden",
        "Description[pl]": "Otwieraj i wypakowuj pliki DEB, RPM, ISO, AppImage, XAR oraz CAB",
        "Description[pt]": "Abrir e extrair ficheiros DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[sk]": "Otvorenie a extrahovanie súborov DEB, RPM, ISO, AppImage, XAR a CAB",
        "Description[sl]": "Odprite in razširite datoteke DEB, RPM, ISO, AppImage, XAR in CAB",
        "Description[sr@ijekavian]": "Отварање и распакивање ДЕБ, РПМ, ИСО, ап‑имејџ, КСАР и КАБ фајлова",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje DEB, RPM, ISO, AppImage, XAR i CAB fajlova",
        "Description[sr@latin]": "Otvaranje i raspakivanje DEB, RPM, ISO, AppImage, XAR i CAB fajlova",
        "Description[sr]": "Отварање и распакивање ДЕБ, РПМ, ИСО, ап‑имејџ, КСАР и КАБ фајлова",
        "Description[sv]": "Öppna och packa upp DEB-, RPM-, ISO-, AppImage-, XAR- och CAB-filer",
        "Description[tr]": "DEB, RPM, ISO, AppImage, XAR ve CAB dosyalarını açıp çıkartın",
        "Description[uk]": "Здатен відкривати і видобувати дані з архівів DEB, RPM, ISO, AppImage, XAR та CAB",
        "Description[x-test]": "xxOpen and extract DEB, RPM, ISO, AppImage, XAR and CAB filesxx",
        "Description[zh_CN]": "打开和解压 DEB，RPM，ISO，AppImage，XAR 和 CAB 文件",
        "Description[zh_TW]": "開啟並解壓縮 DEB, RPM, ISO, AppImage, XAR 與 CAB 檔案",
        "Id": "kerfuffle_libarchive_readonly",
        "MimeTypes": [
            "@SUPPORTED_READONLY_MIMETYPES@"
        ],
        "Name": "Libarchive plugin (read-only formats)",
        "Name[ca@valencia]": "Connector del Libarchive (formats de només lectura)",
        "Name[ca]": "Connector del Libarchive (formats de només lectura)",
        "Name[cs]": "Modul libarchive (formáty pouze pro čtení)",
        "Name[de]": "LibArchive-Modul (Nur lesbare Formate)",
        "Name[el]": "Πρόσθετο Libarchive (ανάγνωση μόνο)",
        "Name[es]": "Complemento Libarchive (formatos de solo lectura)",
        "Name[eu]": "Libarchive plugina (irakurri-soilik formatuak)",
        "Name[fr]": "Module externe libarchive (formats en lecture seule)",
        "Name[it]": "Estensione Libarchive (formati in sola lettura)",
        "Name[nl]": "LibArchive-plug-in (alleen-lezen formaten)",
        "Name[pl]": "Wtyczka Libarchive (formaty tylko-do-odczytu)",
        "Name[pt]": "'Plugin' da Libarchive (formatos apenas para leitura)",
        "Name[sk]": "Plugin Libarchive (formáty iba na čítanie)",
        "Name[sl]": "Vstavek Libarchive (samo za branje)",
        "Name[sr@ijekavian]": "Прикључак за Либархив (формати само‑за‑читање)",
        "Name[sr@ijekavianlatin]": "Priključak za libarchive (formati samo‑za‑čitanje)",
        "Name[sr@latin]": "Priključak za libarchive (formati samo‑za‑čitanje)",
        "Name[sr]": "Прикључак за Либархив (формати само‑за‑читање)",
        "Name[sv]": "Libarchive-insticksprogram (endast läsningsformat)",
        "Name[tr]": "Libarchive eklentisi (salt okunur biçimler)",
        "Name[uk]": "Додаток libarchive (формати лише для читання)",
        "Name[x-test]": "xxLibarchive plugin (read-only formats)xx",
        "Name[zh_CN]": "Libarchive 插件 (只读格式)",
        "Name[zh_TW]": "Libarchive 外掛程式（唯讀格式）",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": false,
    "X-KDE-Priority": 100
}
